{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../../configuration/common

      ./backup-scripts.nix
    ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "palladium";

  networking.useDHCP = false;
  networking.interfaces.enp3s0.ipv6.addresses = [ { address = "2a01:4f8:1c0c:8221::11"; prefixLength = 64; } ];
  networking.defaultGateway6 = { address = "2a01:4f8:1c0c:8221::1"; interface = "enp3s0"; };
  networking.nameservers = [ "fd00:152:152::1" ];

  # Keeping the harddrives quiet
  services.udev.extraRules = ''
    KERNEL=="sd?[0-9]", ENV{ID_MODEL}=="ST1000DM003-1SB102", ACTION=="add", RUN+="${pkgs.hdparm}/sbin/hdparm -S 24 /dev/%k"
  '';

  services.rsnapshot = {
    enable = true;
    extraConfig = ''
      snapshot_root	/mnt/palladium/
      rsync_short_args	-rltD
      retain	alpha	14
      ssh_args	-o BatchMode=yes -o IdentityFile=/var/src/secrets/rsnapshot/id_rsa
      backup	backup-replication@clerie-backup.net.clerie.de:/clerie-backup-replication/*	clerie-backup/
    '';
    # rsync_short_args
    # -a -> -rlptgoD
    # -rltD ist wie -a nur das alle Dateiberechtigungen und Besitzangabe ignoriert werden
    cronIntervals = {
      alpha = "0 9 * * * ";
    };
  };

  clerie.monitoring = {
    enable = true;
    id = "206";
    pubkey = "fHOYNZ5I3E2JPrd9dUrNBmu75weX4KbDih5q+GCk8Xk=";
  };

  system.stateVersion = "21.03";

}
